@@ -117,7 +117,7 @@ KWrited::KWrited() : QObject()
   setegid(original_egid);
 #endif
 
-  pty->login(KUser(KUser::UseRealUserID).loginName().toLocal8Bit().data(), qgetenv("DISPLAY"));
+  pty->login(KUser(KUser::UseRealUserID).loginName().toLocal8Bit().data(), qgetenv("DISPLAY").constData());
   
 #if defined(BUILD_AS_EXECUTABLE)
   //drop privileges again
@@ -161,6 +161,7 @@ void KWrited::block_in()
   notification->setComponentName( QStringLiteral("kwrited") );
 #endif
   notification->setText( msg );
+  notification->setFlags( KNotification::SkipGrouping );
   connect(notification, SIGNAL(closed()), notification, SLOT(deleteLater()) );
   notification->sendEvent();
 }
